==> central-repository-3.59.0.zip: com/microej/pack/fs/fs-testsuite/3.0.8/CHANGELOG-3.0.8.md <==
<!--
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Changed
 - Keep track of upcoming changes here

## [M.m.p] - YYYY-mm-dd

### Changed
  - List here changes in existing functionality

### Added
  - List here the new features.
  
### Deprecated
  - List here soon-to-be removed features.
  
### Fixed
  - List here any bug fixes

### Security
  - List here case of vulnerabilities
-->

## [3.0.8] - 2023-08-16

### Added

  - Add test case which tests that `FileInputStream.read()` reads all available bytes.

## [3.0.7] - 2023-06-14
### Fixed
  -M0074FS-241 Change the properties file extension to `*.properties.list` to be compliant with the architecture 8.

## [3.0.6] - 2022-03-28
### Added
- M0074FS-206 add test covering, milliseconds support in of `java.io.File.lastModified()`.

### Changed
 - Update changelog to use keepachangelog v `1.0.0` format.

### Fixed
- M0074FS-212 fix test TestWriteBigFile in FileTest and TestFileAccess. read was not reading the file completely. 

## [3.0.5] - 2021-09-27
### Changed
  - M0074FS-202 Extract TestRandomSeparator to a Windows-specific test class.

## [3.0.4] - 2021-04-27
### Fixed
  - M0074FS-179 Fix TestWriteWithOffset, don't open twice (in read and write mode) the same file at the same time.

## [3.0.3] - 2020-10-09
### Fixed
  - M0074FS-166: NullPointerException on test TestGetCanonicalPath.
  
  
## [3.0.2] - 2020-08-29
### Fixed
  - M0074FS-165: Invalid test on canonical path.
  
## [3.0.1] - 2020-05-27
### Fixed
  - Flush FileOutputStream after writing data.
  
## [3.0.0] - 2020-01-29
### Changed
  - Changed module name & organization.
  - Renamed Java package to `com.microej`.
  - Relicensed to BSP/SDK dual.

## [2.3.0] - 2019-05-31
### Fixed
  - M0074FS-116: Add smaller negative values in TestSkip, add TestNegativeSkipWhenSupported.
  - M0074FS-117: Add TestReadWithOffset and TestWriteWithOffset.
  - M0074FS-112: Clean the user dir and tmpdir before launching tests.

---
_Copyright 2019-2023 MicroEJ Corp. All rights reserved._  
_This library is provided in source code for use, modification and test, subject to license terms._  
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._

==> central-repository-3.62.0.zip: com/microej/pack/fs/fs-testsuite/3.0.5/CHANGELOG-3.0.5.md <==
<!--
# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Changed
 - Keep track of upcoming changes here

## [M.m.p] - YYYY-mm-dd

### Changed
  - List here changes in existing functionality

### Added
  - List here the new features.
  
### Deprecated
  - List here soon-to-be removed features.
  
### Fixed
  - List here any bug fixes

### Security
  - List here case of vulnerabilities
-->

## [3.0.5] - (2021-09-27)

### Changed
  - M0074FS-202 Extract TestRandomSeparator to a Windows-specific test class.


## [3.0.4] - (2021-04-27)

### Fixed
  - M0074FS-179 Fix TestWriteWithOffset, don't open twice (in read and write mode) the same file at the same time.


## [3.0.3] - (2020-10-09)

### Fixed
  - M0074FS-166: NullPointerException on test TestGetCanonicalPath
  
  
## [3.0.2] - (2020-08-29)

### Fixed
  - M0074FS-165: Invalid test on canonical path
  
## [3.0.1] - (2020-05-27)

### Fixed
  - Flush FileOutputStream after writing data
  
## [3.0.0] - 2020-01-29

### Changed
  - Changed module name & organization
  - Renamed Java package to com.microej
  - Relicensed to BSP/SDK dual

## [2.3.0] - 2019-05-31

### Fixed
  - M0074FS-116: Add smaller negative values in TestSkip, add TestNegativeSkipWhenSupported
  - M0074FS-117: Add TestReadWithOffset and TestWriteWithOffset
  - M0074FS-112: Clean the user dir and tmpdir before launching tests

---
_Copyright 2019-2021 MicroEJ Corp. All rights reserved._  
_This library is provided in source code for use, modification and test, subject to license terms._  
_Any modification of the source code will break MicroEJ Corp. warranties on the whole library._
